@@ -6,7 +6,7 @@ from django.utils.unittest.suite import TestSuite
 
 def suite():
     s = TestSuite()
-    # s.addTest(test_suite())
+    s.addTest(test_suite())
     s.addTest(lost_keys_suite())
-    # s.addTest(member_suite())
+    s.addTest(member_suite())
     return s
