@@ -26,3 +26,7 @@ VAULTIER.update({
 })
 
 SECRET_KEY = 'DEV_KEY_DEV_KEY_DEV_KEY_DEV_KEY_'
+
+# Celery
+CELERY_ALWAYS_EAGER = True
+CELERY_EAGER_PROPAGATES_EXCEPTIONS = True
